@@ -77,6 +77,7 @@ class ModelType(type):
         _set_meta_attr('exclude_fields_down', ())
         _set_meta_attr('exclude_values_up', {'':()}, mutable=True)
         _set_meta_attr('exclude_values_down', {'':()}, mutable=True)
+        _set_meta_attr('ignore_init_exclude_error', True)
         _set_meta_attr('_field_defs_', {}, internal=True, mutable=True)
 
         if meta_attrs['proxy']:
@@ -256,15 +257,16 @@ class ModelType(type):
             res[k] = all_fields[k].to_json()
         return res
 
-    def _run_validations_(self, k: str, v: FieldValue):
+    def _run_validations_(self, k: str, v: FieldValue, mob=None) -> FieldValue:
         try:
-            validator = getattr(self, '_clean_' + k)
-            v.value = validator(self, v.value)
+            validator = getattr(mob, '_clean_' + k)
+            v.value = validator(v.value)
         except AttributeError:
             v.value = v.value # at least trigger the value validation
+        return v
 
 
-    def _get_FieldValue_data_valid_(self, data: dict, up=False, validate_all=False) -> Iterator[Tuple[str, Any]]:
+    def _get_FieldValue_data_valid_(self, data: dict, up=False, validate_all=False, mob=None) -> Iterator[Tuple[str, Any]]:
         """Yields valid key,value pairs from data.
 
         Validity is checked against include/exclude key/value criteria.
@@ -286,13 +288,13 @@ class ModelType(type):
             exclude_fields = self.Meta.exclude_fields_down
         # new_data = type(data)()
         for k,v in data.items():
-            if validate_all: self._run_validations_(k, v)
+            if validate_all: v = self._run_validations_(k, v, mob)
             if not self._is_valid_key_(k, fields, exclude_fields):
                 continue
             if not self._is_valid_value_(k, v.value, exclude_values):
                 continue
             if not validate_all: # run validations for to-be-changed fields only
-                self._run_validations_(k, v)
+                v = self._run_validations_(k, v, mob)
             yield k, v
 
 
@@ -384,11 +386,13 @@ class ModelBase(metaclass=ModelType):
         exclude_fields_down = ()
         exclude_values_up = {'':()}
         exclude_values_down = {'':()}
+        ignore_init_exclude_error = True
 
         #internal
         _field_defs_: Dict[str, Field]
         _fields_: Dict[str, FieldValue]
         _fromdb_: List[str]
+        _initializing_: bool = False
 
 
     def __init__(self, *args, **kwargs):
@@ -397,6 +401,7 @@ class ModelBase(metaclass=ModelType):
             _fromdb_: List[str] = []
         # super(ModelBase, self).__setattr__('Meta', Meta)
         self.__dict__['Meta'] = Meta
+        self.Meta._initializing_ = True
         for k, v in self.__class__.Meta._field_defs_.items():
             self.Meta._fields_[k] = FieldValue(v)
         for arg in args:
@@ -408,6 +413,7 @@ class ModelBase(metaclass=ModelType):
                 setattr(self, k, v)
         for k,v in kwargs.items():
             setattr(self, k, v)
+        self.Meta._initializing_ = False
 
     def __iter__(self):
         """Iter through k, v where k is field name and v is field value
@@ -456,10 +462,14 @@ class ModelBase(metaclass=ModelType):
             elif self.__class__._is_valid_up_(k, v):
                 fields[k]._ignore_first_change_count_ = True
                 fields[k].value = v
+            elif self.__class__.Meta.ignore_init_exclude_error and self.Meta._initializing_: # ignore this error at init
+                return
             else:
                 raise AttributeError(f'Can not set field `{k}`. It is excluded using either exclude_fields_up/down or exclude_values_up/down in {self.__class__.__name__} Meta class. Or you are trying to set an invalid value: {v}')
         elif self.__class__._is_valid_up_(k, v):
             fields[k].value = v
+        elif self.__class__.Meta.ignore_init_exclude_error and self.Meta._initializing_: # ignore this error at init
+            return
         else:
             raise AttributeError(f'Can not set field `{k}`. It is excluded using either exclude_fields_up/down or exclude_values_up/down in {self.__class__.__name__} Meta class. Or you are trying to set an invalid value: {v}')
 
